@@ -22,7 +22,8 @@ class WriterBase:
     def iterateOnFilesAndDirectories(self, directory, output_directory):
         for (dirpath, dirnames, filenames) in walk(directory):
             for filename in filenames:
-                if filename.endswith('.yml'):
+                #ignore any existing md files
+                if not filename.endswith('.md'):
                     self.createMDFile(dirpath, filename, output_directory)
 
             for dirname in dirnames:
